@@ -11,18 +11,20 @@ impl<'src> Analyzer<'src> {
   pub(crate) fn analyze(
     asts: &HashMap<PathBuf, Ast<'src>>,
     doc: Option<String>,
+    groups: &[String],
     loaded: &[PathBuf],
     name: Option<Name<'src>>,
     paths: &HashMap<PathBuf, PathBuf>,
     root: &Path,
   ) -> CompileResult<'src, Justfile<'src>> {
-    Self::default().justfile(asts, doc, loaded, name, paths, root)
+    Self::default().justfile(asts, doc, groups, loaded, name, paths, root)
   }
 
   fn justfile(
     mut self,
     asts: &HashMap<PathBuf, Ast<'src>>,
     doc: Option<String>,
+    groups: &[String],
     loaded: &[PathBuf],
     name: Option<Name<'src>>,
     paths: &HashMap<PathBuf, PathBuf>,
@@ -33,7 +35,8 @@ impl<'src> Analyzer<'src> {
     let mut assignments = Vec::new();
 
     let mut stack = Vec::new();
-    stack.push(asts.get(root).unwrap());
+    let ast = asts.get(root).unwrap();
+    stack.push(ast);
 
     let mut warnings = Vec::new();
 
@@ -94,9 +97,12 @@ impl<'src> Analyzer<'src> {
             ..
           } => {
             let mut doc_attr: Option<&str> = None;
+            let mut groups = Vec::new();
             for attribute in attributes {
               if let Attribute::Doc(ref doc) = attribute {
                 doc_attr = Some(doc.as_ref().map(|s| s.cooked.as_ref()).unwrap_or_default());
+              } else if let Attribute::Group(ref group) = attribute {
+                groups.push(group.cooked.clone());
               } else {
                 return Err(name.token.error(InvalidAttribute {
                   item_kind: "Module",
@@ -111,6 +117,7 @@ impl<'src> Analyzer<'src> {
               modules.insert(Self::analyze(
                 asts,
                 doc_attr.or(*doc).map(ToOwned::to_owned),
+                groups.as_slice(),
                 loaded,
                 Some(*name),
                 paths,
@@ -186,17 +193,20 @@ impl<'src> Analyzer<'src> {
 
     let root = paths.get(root).unwrap();
 
-    let unstable_features = recipes
-      .values()
-      .flat_map(|recipe| &recipe.attributes)
-      .filter_map(|attribute| {
+    let mut unstable_features = BTreeSet::new();
+
+    for recipe in recipes.values() {
+      for attribute in &recipe.attributes {
         if let Attribute::Script(_) = attribute {
-          Some(UnstableFeature::ScriptAttribute)
-        } else {
-          None
+          unstable_features.insert(UnstableFeature::ScriptAttribute);
+          break;
         }
-      })
-      .collect();
+      }
+    }
+
+    if settings.script_interpreter.is_some() {
+      unstable_features.insert(UnstableFeature::ScriptInterpreterSetting);
+    }
 
     Ok(Justfile {
       aliases,
@@ -213,6 +223,7 @@ impl<'src> Analyzer<'src> {
           }),
         }),
       doc,
+      groups: groups.into(),
       loaded: loaded.into(),
       modules,
       name,
@@ -222,6 +233,7 @@ impl<'src> Analyzer<'src> {
       unexports,
       unstable_features,
       warnings,
+      working_directory: ast.working_directory.clone(),
     })
   }
 
