@@ -38,6 +38,7 @@ impl Color {
     }
   }
 
+  #[cfg(test)]
   pub(crate) fn always() -> Self {
     Self {
       use_color: UseColor::Always,
@@ -133,6 +134,15 @@ impl Color {
   }
 }
 
+impl From<UseColor> for Color {
+  fn from(use_color: UseColor) -> Self {
+    Self {
+      use_color,
+      ..Default::default()
+    }
+  }
+}
+
 impl Default for Color {
   fn default() -> Self {
     Self {
