@@ -30,7 +30,7 @@ impl<'line> Shebang<'line> {
     })
   }
 
-  fn interpreter_filename(&self) -> &str {
+  pub fn interpreter_filename(&self) -> &str {
     self
       .interpreter
       .split(|c| matches!(c, '/' | '\\'))
@@ -38,14 +38,6 @@ impl<'line> Shebang<'line> {
       .unwrap_or(self.interpreter)
   }
 
-  pub(crate) fn script_filename(&self, recipe: &str) -> String {
-    match self.interpreter_filename() {
-      "cmd" | "cmd.exe" => format!("{recipe}.bat"),
-      "powershell" | "powershell.exe" | "pwsh" | "pwsh.exe" => format!("{recipe}.ps1"),
-      _ => recipe.to_owned(),
-    }
-  }
-
   pub(crate) fn include_shebang_line(&self) -> bool {
     !(cfg!(windows) || matches!(self.interpreter_filename(), "cmd" | "cmd.exe"))
   }
@@ -135,61 +127,6 @@ mod tests {
     );
   }
 
-  #[test]
-  fn powershell_script_filename() {
-    assert_eq!(
-      Shebang::new("#!powershell").unwrap().script_filename("foo"),
-      "foo.ps1"
-    );
-  }
-
-  #[test]
-  fn pwsh_script_filename() {
-    assert_eq!(
-      Shebang::new("#!pwsh").unwrap().script_filename("foo"),
-      "foo.ps1"
-    );
-  }
-
-  #[test]
-  fn powershell_exe_script_filename() {
-    assert_eq!(
-      Shebang::new("#!powershell.exe")
-        .unwrap()
-        .script_filename("foo"),
-      "foo.ps1"
-    );
-  }
-
-  #[test]
-  fn pwsh_exe_script_filename() {
-    assert_eq!(
-      Shebang::new("#!pwsh.exe").unwrap().script_filename("foo"),
-      "foo.ps1"
-    );
-  }
-
-  #[test]
-  fn cmd_script_filename() {
-    assert_eq!(
-      Shebang::new("#!cmd").unwrap().script_filename("foo"),
-      "foo.bat"
-    );
-  }
-
-  #[test]
-  fn cmd_exe_script_filename() {
-    assert_eq!(
-      Shebang::new("#!cmd.exe").unwrap().script_filename("foo"),
-      "foo.bat"
-    );
-  }
-
-  #[test]
-  fn plain_script_filename() {
-    assert_eq!(Shebang::new("#!bar").unwrap().script_filename("foo"), "foo");
-  }
-
   #[test]
   fn dont_include_shebang_line_cmd() {
     assert!(!Shebang::new("#!cmd").unwrap().include_shebang_line());
