@@ -3,7 +3,7 @@ use super::*;
 fn case(justfile: &str, value: Value) {
   Test::new()
     .justfile(justfile)
-    .args(["--dump", "--dump-format", "json", "--unstable"])
+    .args(["--dump", "--dump-format", "json"])
     .stdout(format!("{}\n", serde_json::to_string(&value).unwrap()))
     .run();
 }
@@ -18,6 +18,7 @@ fn alias() {
     ",
     json!({
       "first": "foo",
+      "doc": null,
       "aliases": {
         "f": {
           "name": "f",
@@ -26,6 +27,7 @@ fn alias() {
         }
       },
       "assignments": {},
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -55,9 +57,12 @@ fn alias() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "ignore_comments": false,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -80,6 +85,8 @@ fn assignment() {
         }
       },
       "first": null,
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {},
       "settings": {
@@ -96,8 +103,10 @@ fn assignment() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -117,6 +126,8 @@ fn body() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -150,8 +161,10 @@ fn body() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -170,6 +183,8 @@ fn dependencies() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "bar": {
@@ -216,8 +231,10 @@ fn dependencies() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -248,6 +265,7 @@ fn dependency_argument() {
     json!({
       "aliases": {},
       "first": "foo",
+      "doc": null,
       "assignments": {
         "x": {
           "export": false,
@@ -256,6 +274,7 @@ fn dependency_argument() {
           "depth": 0,
         },
       },
+      "groups": [],
       "modules": {},
       "recipes": {
         "bar": {
@@ -320,8 +339,10 @@ fn dependency_argument() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -341,6 +362,7 @@ fn duplicate_recipes() {
     ",
     json!({
       "first": "foo",
+      "doc": null,
       "aliases": {
         "f": {
           "attributes": [],
@@ -349,6 +371,7 @@ fn duplicate_recipes() {
         }
       },
       "assignments": {},
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -386,8 +409,10 @@ fn duplicate_recipes() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -414,6 +439,8 @@ fn duplicate_variables() {
         }
       },
       "first": null,
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {},
       "settings": {
@@ -430,8 +457,10 @@ fn duplicate_variables() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -446,7 +475,9 @@ fn doc_comment() {
     json!({
       "aliases": {},
       "first": "foo",
+      "doc": null,
       "assignments": {},
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -477,8 +508,10 @@ fn doc_comment() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -494,6 +527,8 @@ fn empty_justfile() {
       "aliases": {},
       "assignments": {},
       "first": null,
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {},
       "settings": {
@@ -510,8 +545,10 @@ fn empty_justfile() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -533,7 +570,9 @@ fn parameters() {
     json!({
       "aliases": {},
       "first": "a",
+      "doc": null,
       "assignments": {},
+      "groups": [],
       "modules": {},
       "recipes": {
         "a": {
@@ -664,8 +703,10 @@ fn parameters() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -685,6 +726,8 @@ fn priors() {
       "aliases": {},
       "assignments": {},
       "first": "a",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "a": {
@@ -751,8 +794,10 @@ fn priors() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -768,6 +813,8 @@ fn private() {
       "aliases": {},
       "assignments": {},
       "first": "_foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "_foo": {
@@ -798,8 +845,10 @@ fn private() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -815,6 +864,8 @@ fn quiet() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -845,8 +896,10 @@ fn quiet() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -874,6 +927,8 @@ fn settings() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -907,8 +962,10 @@ fn settings() {
           "command": "a",
         },
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -927,6 +984,8 @@ fn shebang() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -957,8 +1016,10 @@ fn shebang() {
         "quiet": false,
         "shell": null,
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -974,6 +1035,8 @@ fn simple() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -1004,8 +1067,10 @@ fn simple() {
         "quiet": false,
         "shell": null,
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -1024,6 +1089,8 @@ fn attribute() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "doc": null,
+      "groups": [],
       "modules": {},
       "recipes": {
         "foo": {
@@ -1053,9 +1120,11 @@ fn attribute() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
+        "working_directory" : null,
       },
       "unexports": [],
       "warnings": [],
@@ -1068,25 +1137,29 @@ fn module() {
   Test::new()
     .justfile(
       "
+      # hello
       mod foo
     ",
     )
     .tree(tree! {
       "foo.just": "bar:",
     })
-    .args(["--dump", "--dump-format", "json", "--unstable"])
-    .test_round_trip(false)
+    .args(["--dump", "--dump-format", "json"])
     .stdout(format!(
       "{}\n",
       serde_json::to_string(&json!({
         "aliases": {},
         "assignments": {},
         "first": null,
+        "doc": null,
+        "groups": [],
         "modules": {
           "foo": {
             "aliases": {},
             "assignments": {},
             "first": "bar",
+            "doc": "hello",
+            "groups": [],
             "modules": {},
             "recipes": {
               "bar": {
@@ -1116,9 +1189,11 @@ fn module() {
               "quiet": false,
               "shell": null,
               "tempdir" : null,
+              "unstable": false,
               "ignore_comments": false,
               "windows_powershell": false,
               "windows_shell": null,
+              "working_directory" : null,
             },
             "unexports": [],
             "warnings": [],
@@ -1138,9 +1213,106 @@ fn module() {
           "quiet": false,
           "shell": null,
           "tempdir" : null,
+          "unstable": false,
           "ignore_comments": false,
           "windows_powershell": false,
           "windows_shell": null,
+          "working_directory" : null,
+        },
+        "unexports": [],
+        "warnings": [],
+      }))
+      .unwrap()
+    ))
+    .run();
+}
+
+#[test]
+fn module_group() {
+  Test::new()
+    .justfile(
+      "
+      [group('alpha')]
+      mod foo
+    ",
+    )
+    .tree(tree! {
+      "foo.just": "bar:",
+    })
+    .args(["--dump", "--dump-format", "json"])
+    .stdout(format!(
+      "{}\n",
+      serde_json::to_string(&json!({
+        "aliases": {},
+        "assignments": {},
+        "first": null,
+        "doc": null,
+        "groups": [],
+        "modules": {
+          "foo": {
+            "aliases": {},
+            "assignments": {},
+            "first": "bar",
+            "doc": null,
+            "groups": ["alpha"],
+            "modules": {},
+            "recipes": {
+              "bar": {
+                "attributes": [],
+                "body": [],
+                "dependencies": [],
+                "doc": null,
+                "name": "bar",
+                "namepath": "foo::bar",
+                "parameters": [],
+                "priors": 0,
+                "private": false,
+                "quiet": false,
+                "shebang": false,
+              }
+            },
+            "settings": {
+              "allow_duplicate_recipes": false,
+              "allow_duplicate_variables": false,
+              "dotenv_filename": null,
+              "dotenv_load": false,
+              "dotenv_path": null,
+              "dotenv_required": false,
+              "export": false,
+              "fallback": false,
+              "positional_arguments": false,
+              "quiet": false,
+              "shell": null,
+              "tempdir" : null,
+              "unstable": false,
+              "ignore_comments": false,
+              "windows_powershell": false,
+              "windows_shell": null,
+              "working_directory" : null,
+            },
+            "unexports": [],
+            "warnings": [],
+          },
+        },
+        "recipes": {},
+        "settings": {
+          "allow_duplicate_recipes": false,
+          "allow_duplicate_variables": false,
+          "dotenv_filename": null,
+          "dotenv_load": false,
+          "dotenv_path": null,
+          "dotenv_required": false,
+          "export": false,
+          "fallback": false,
+          "positional_arguments": false,
+          "quiet": false,
+          "shell": null,
+          "tempdir" : null,
+          "unstable": false,
+          "ignore_comments": false,
+          "windows_powershell": false,
+          "windows_shell": null,
+          "working_directory" : null,
         },
         "unexports": [],
         "warnings": [],
