@@ -19,7 +19,7 @@ pub(crate) use {
     fs,
     io::Write,
     iter,
-    path::{Path, PathBuf, MAIN_SEPARATOR},
+    path::{Path, PathBuf, MAIN_SEPARATOR, MAIN_SEPARATOR_STR},
     process::{Command, Stdio},
     str,
   },
@@ -90,6 +90,7 @@ mod readme;
 mod recursion_limit;
 mod regexes;
 mod run;
+mod script;
 mod search;
 mod search_arguments;
 mod shadowing_parameters;
